Bug 1396997 - Update try pretty names for stylo-disabled jobs. r=froydnj draft
authorJ. Ryan Stinnett <jryans@gmail.com>
Tue, 05 Sep 2017 15:52:52 -0500
changeset 660176 bfb4c02a660c76ca676ce1ecd84b97c9f7468479
parent 659132 9f9220182fb9d662da64b7f0e710fecd2f2dac82
child 730143 c8cf3e7ae544fac1b51f1c1c28016b220c4b056b
push id78299
push userbmo:jryans@gmail.com
push dateWed, 06 Sep 2017 16:47:20 +0000
reviewersfroydnj
bugs1396997
milestone57.0a1
Bug 1396997 - Update try pretty names for stylo-disabled jobs. r=froydnj MozReview-Commit-ID: 9N54Hot4LdF
taskcluster/taskgraph/test/test_try_option_syntax.py
taskcluster/taskgraph/try_option_syntax.py
--- a/taskcluster/taskgraph/try_option_syntax.py
+++ b/taskcluster/taskgraph/try_option_syntax.py
@@ -118,18 +118,29 @@ UNITTEST_ALIASES = {
 # substrings.  It is OK to add new test platforms to various shorthands here;
 # if you add a new Linux64 test platform for instance, people will expect that
 # their previous methods of requesting "all linux64 tests" will include this
 # new platform, and they shouldn't have to explicitly spell out the new platform
 # every time for such cases.
 #
 # Note that the test platforms here are only the prefix up to the `/`.
 UNITTEST_PLATFORM_PRETTY_NAMES = {
-    'Ubuntu': ['linux32', 'linux64', 'linux64-asan', 'linux64-stylo', 'linux64-stylo-sequential'],
-    'x64': ['linux64', 'linux64-asan', 'linux64-stylo', 'linux64-stylo-sequential'],
+    'Ubuntu': [
+        'linux32',
+        'linux64',
+        'linux64-asan',
+        'linux64-stylo-disabled',
+        'linux64-stylo-sequential'
+    ],
+    'x64': [
+        'linux64',
+        'linux64-asan',
+        'linux64-stylo-disabled',
+        'linux64-stylo-sequential'
+    ],
     'Android 4.3': ['android-4.3-arm7-api-16'],
     '10.10': ['macosx64'],
     # other commonly-used substrings for platforms not yet supported with
     # in-tree taskgraphs:
     # '10.10.5': [..TODO..],
     # '10.6': [..TODO..],
     # '10.8': [..TODO..],
     # 'Android 2.3 API9': [..TODO..],
--- a/taskcluster/taskgraph/test/test_try_option_syntax.py
+++ b/taskcluster/taskgraph/test/test_try_option_syntax.py
@@ -224,22 +224,22 @@ class TestTryOptionSyntax(unittest.TestC
     def test_u_platforms(self):
         "-u gtest[linux,win32] selects the linux and win32 platforms for gtest"
         tos = TryOptionSyntax('try: -u gtest[linux,win32]', graph_with_jobs)
         self.assertEqual(sorted(tos.unittests), sorted([
             {'test': 'gtest', 'platforms': ['linux', 'win32']},
         ]))
 
     def test_u_platforms_pretty(self):
         """-u gtest[Ubuntu] selects the linux, linux64, linux64-asan, linux64-stylo,
         and linux64-stylo-sequential platforms for gtest"""
         tos = TryOptionSyntax('try: -u gtest[Ubuntu]', graph_with_jobs)
         self.assertEqual(sorted(tos.unittests), sorted([
             {'test': 'gtest', 'platforms': ['linux32', 'linux64', 'linux64-asan',
-                                            'linux64-stylo', 'linux64-stylo-sequential']},
+                                            'linux64-stylo-disabled', 'linux64-stylo-sequential']},
         ]))
 
     def test_u_platforms_negated(self):
@@ -224,22 +224,22 @@ class TestTryOptionSyntax(unittest.TestC
 
     def test_u_platforms_pretty(self):
-        """-u gtest[Ubuntu] selects the linux, linux64, linux64-asan, linux64-stylo,
+        """-u gtest[Ubuntu] selects the linux, linux64, linux64-asan, linux64-stylo-disabled,
         and linux64-stylo-sequential platforms for gtest"""
         tos = TryOptionSyntax('try: -u gtest[Ubuntu]', graph_with_jobs)
         "-u gtest[-linux] selects all platforms but linux for gtest"
         tos = TryOptionSyntax('try: -u gtest[-linux]', graph_with_jobs)
         all_platforms = set([x.attributes['test_platform'] for x in unittest_tasks.values()])
         self.assertEqual(sorted(tos.unittests[0]['platforms']), sorted(
             [x for x in all_platforms if x != 'linux']